summary refs log tree commit diff
path: root/drivers/md/dm-exception-store.h
diff options
context:
space:
mode:
authorMikulas Patocka <mpatocka@redhat.com>2010-08-12 04:13:51 +0100
committerAlasdair G Kergon <agk@redhat.com>2010-08-12 04:13:51 +0100
commitc24110450650f17f7d3ba4fbe01f01ac5a115456 (patch)
tree8b5bff17f77c995099d93b2b4a32bc306962a0bf /drivers/md/dm-exception-store.h
parent1e5554c8428bc7209a83e2d07ca724be4d981ce3 (diff)
downloadlinux-c24110450650f17f7d3ba4fbe01f01ac5a115456.tar.gz
dm snapshot: test chunk size against both origin and snapshot
Validate chunk size against both origin and snapshot sector size

Don't allow chunk size smaller than either origin or snapshot logical
sector size. Reading or writing data not aligned to sector size is not
allowed and causes immediate errors.

This requires us to open the origin before initialising the
exception store and to export dm_snap_origin.

Cc: stable@kernel.org
Signed-off-by: Mikulas Patocka <mpatocka@redhat.com>
Reviewed-by: Mike Snitzer <snitzer@redhat.com>
Signed-off-by: Alasdair G Kergon <agk@redhat.com>
Diffstat (limited to 'drivers/md/dm-exception-store.h')
-rw-r--r--drivers/md/dm-exception-store.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/drivers/md/dm-exception-store.h b/drivers/md/dm-exception-store.h
index e8dfa06af3ba..0b2536247cf5 100644
--- a/drivers/md/dm-exception-store.h
+++ b/drivers/md/dm-exception-store.h
@@ -126,8 +126,9 @@ struct dm_exception_store {
 };
 
 /*
  * Obtain the cow device used by a given snapshot.
  */
+struct dm_dev *dm_snap_origin(struct dm_snapshot *snap);
 struct dm_dev *dm_snap_cow(struct dm_snapshot *snap);
 
 /*
@@ -126,8 +126,9 @@ struct dm_exception_store {
 
 /*
- * Obtain the cow device used by a given snapshot.
+ * Obtain the origin or cow device used by a given snapshot.
  */